<?php
/**
 *    com_simplecalendar - a simple calendar component for Joomla
 *  Copyright (C) 2008-2013 Fabrizio Albonico
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *    (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

defined('_JEXEC') or die;

/**
 * SimpleCalendar list controller class.
 *
 */
class SimplecalendarControllerEvents extends JControllerAdmin
{
	/**
	 * @var        string    The prefix to use with controller messages.
	 * @since   1.6
	 */
	protected $text_prefix = 'COM_SIMPLECALENDAR_EVENTS';

	/**
	 * Constructor.
	 *
	 * @param   array An optional associative array of configuration settings.
	 *
	 * @see     JController
	 * @since   1.6
	 */
	public function __construct($config = array())
	{
		parent::__construct($config);
		$this->registerTask('unfeatured', 'featured');
	}

	/**
	 * Proxy for getModel.
	 *
	 * @since   1.6
	 */
	public function getModel($name = 'Event', $prefix = 'SimpleCalendarModel', $config = array('ignore_request' => true))
	{
		$model = parent::getModel($name, $prefix, $config);

		return $model;
	}

	public function featured()
	{
		// Check for request forgeries
		JSession::checkToken() or jexit(JText::_('JINVALID_TOKEN'));

		$user   = JFactory::getUser();
		$ids    = $this->input->get('cid', array(), 'array');
		$values = array('featured' => 1, 'unfeatured' => 0);
		$task   = $this->getTask();
		$value  = \Joomla\Utilities\ArrayHelper::getValue($values, $task, 0, 'int');

		// Access checks.
		foreach ($ids as $i => $id)
		{
			if (!$user->authorise('core.edit.state', 'com_simplecalendar.event.' . (int) $id))
			{
				// Prune items that you can't change.
				unset($ids[$i]);
				JFactory::getApplication()->enqueueMessage(JText::_('JLIB_APPLICATION_ERROR_EDITSTATE_NOT_PERMITTED'), 'notice');
			}
		}

		if (empty($ids))
		{
			JFactory::getApplication()->enqueueMessage(JText::_('JERROR_NO_ITEMS_SELECTED'), 'warning');
		}
		else
		{
			// Get the model.
			$model = $this->getModel();

			// Publish the items.
			if (!$model->featured($ids, $value))
			{
				JFactory::getApplication()->enqueueMessage($model->getError(), 'warning');
			}
		}

		$this->setRedirect('index.php?option=com_simplecalendar&view=events');
	}

	public function export()
	{
		// get the selected ids:
		$ids = $this->input->get('cid', array(), 'array');

		// Get the model.
		$model = $this->getModel('Events');

		if (sizeof($ids) > 0)
		{
			$delimiter = ';';

			$entries = $model->getItemsForExport('*', $ids);

			// create a file pointer connected to the output stream
			$output = fopen('php://output', 'w');

			// Use correct encoding (UTF_8)
			fprintf($output, chr(0xEF) . chr(0xBB) . chr(0xBF));

			fputcsv($output, array_keys($entries[0]), $delimiter);

			foreach ($entries as $row)
			{
				$row = str_replace(array("\r\n", "\r", "\n"), "<br />", $row);
				fputcsv($output, $row, $delimiter);
			}

			fclose($output);

			// Dump to CSV file;
			header('Content-Type: application/csv');
			header('Content-Disposition: attachment; filename="scexport.csv";');
			exit;
		}
		else
		{
			JFactory::getApplication()->enqueueMessage($model->getError(), 'warning');
			$this->setRedirect('index.php?option=com_simplecalendar&view=events', 'COM_SIMPLECALENDAR_');
		}
	}
}
