<?php
/**
 *    com_simplecalendar - a simple calendar component for Joomla
 *  Copyright (C) 2008-2013 Fabrizio Albonico
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *    (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

defined('_JEXEC') or die;

/**
 * Simplecalendar Event model (Admin backend)
 *
 * @package     Joomla.Administrator
 * @subpackage  com_simplecalendar
 * @since       3.0
 */
class SimplecalendarModelEvent extends JModelAdmin
{
	/**
	 * @var    string  The prefix to use with controller messages.
	 * @since  1.6
	 */
	protected $text_prefix = 'COM_SIMPLECALENDAR_EVENT';

	/**
	 * Method to perform batch operations on an item or a set of items.
	 *
	 * @param   array $commands An array of commands to perform.
	 * @param   array $pks      An array of item ids.
	 * @param   array $contexts An array of item contexts.
	 *
	 * @return  boolean   Returns true on success, false on failure.
	 *
	 * @since    2.5
	 */
	public function batch($commands, $pks, $contexts)
	{
		// Sanitize user ids.
		$pks = array_unique($pks);
		\Joomla\Utilities\ArrayHelper::toInteger($pks);

		// Remove any values of zero.
		if (array_search(0, $pks, true))
		{
			unset($pks[array_search(0, $pks, true)]);
		}

		if (empty($pks))
		{
			JFactory::getApplication()->enqueueMessage(JText::_('JGLOBAL_NO_ITEM_SELECTED'), 'warning');

			return false;
		}

		$done = false;

		if (!empty($commands['category_id']))
		{
			$cmd = \Joomla\Utilities\ArrayHelper::getValue($commands, 'move_copy', 'c');

			if ($cmd == 'c')
			{
				$result = $this->batchCopy($commands['category_id'], $pks, $contexts);
				if (is_array($result))
				{
					$pks = $result;
				}
				else
				{
					return false;
				}
			}
			elseif ($cmd == 'm' && !$this->batchMove($commands['category_id'], $pks, $contexts))
			{
				return false;
			}
			$done = true;
		}

		if (strlen($commands['client_id']) > 0)
		{
			if (!$this->batchClient($commands['client_id'], $pks, $contexts))
			{
				return false;
			}

			$done = true;
		}

		// if (!empty($commands['language_id']))
		// {
		// if (!$this->batchLanguage($commands['language_id'], $pks, $contexts))
		// {
		// return false;
		// }
// 
		// $done = true;
		// }

		if (!$done)
		{
			JFactory::getApplication()->enqueueMessage(JText::_('JLIB_APPLICATION_ERROR_INSUFFICIENT_BATCH_INFORMATION'), 'error');

			return false;
		}

		// Clear the cache
		$this->cleanCache();

		return true;
	}

	/**
	 * Batch copy items to a new category or current.
	 *
	 * @param   integer $value    The new category.
	 * @param   array   $pks      An array of row IDs.
	 * @param   array   $contexts An array of item contexts.
	 *
	 * @return  mixed  An array of new IDs on success, boolean false on failure.
	 *
	 * @since    2.5
	 */
	protected function batchCopy($value, $pks, $contexts)
	{
		$categoryId = (int) $value;

		$table  = $this->getTable();
		$i      = 0;
		$newIds = array();

		// Check that the category exists
		if ($categoryId)
		{
			$categoryTable = JTable::getInstance('Category');

			try
			{
				$categoryTable->load($categoryId);
			} catch (Exception $ex)
			{
				JFactory::getApplication()->enqueueMessage($ex->getMessage(), 'error');

				return false;
			}

			/*if (!$categoryTable->load($categoryId))
			{
				if ($error = $categoryTable->getError())
				{
					// Fatal error
					JFactory::getApplication()->enqueueMessage($error, 'error');

					return false;
				}
				else
				{
					JFactory::getApplication()->enqueueMessage(JText::_('JLIB_APPLICATION_ERROR_BATCH_MOVE_CATEGORY_NOT_FOUND'), 'error');

					return false;
				}
			}*/
		}

		if (empty($categoryId))
		{
			JFactory::getApplication()->enqueueMessage(JText::_('JLIB_APPLICATION_ERROR_BATCH_MOVE_CATEGORY_NOT_FOUND'), 'error');

			return false;
		}

		// Check that the user has create permission for the component
		$user = JFactory::getUser();
		if (!$user->authorise('core.create', 'com_simplecalendar.category.' . $categoryId))
		{

			JFactory::getApplication()->enqueueMessage(JText::_('JLIB_APPLICATION_ERROR_BATCH_CANNOT_CREATE'), 'error');

			return false;
		}

		// Parent exists so we let's proceed
		while (!empty($pks))
		{
			// Pop the first ID off the stack
			$pk = array_shift($pks);

			$table->reset();

			// Check that the row actually exists
			if (!$table->load($pk))
			{
				if ($error = $table->getError())
				{
					// Fatal error
					JFactory::getApplication()->enqueueMessage($error, 'error');

					return false;
				}
				else
				{
					// Not fatal error
					JFactory::getApplication()->enqueueMessage(JText::sprintf('JLIB_APPLICATION_ERROR_BATCH_MOVE_ROW_NOT_FOUND', $pk), 'error');
					continue;
				}
			}

			// Alter the title & alias
			$data         = $this->generateNewTitle($categoryId, $table->alias, $table->name);
			$table->name  = $data['0'];
			$table->alias = $data['1'];

			// Reset the ID because we are making a copy
			$table->id = 0;

			// New category ID
			$table->catid = $categoryId;

			// Check the row.
			try
			{
				$table->check();
			} catch (Exception $ex)
			{
				JFactory::getApplication()->enqueueMessage($ex->getMessage(), 'error');

				return false;
			}

			// Store the row.
			try
			{
				$table->store();
			} catch (Exception $ex)
			{
				JFactory::getApplication()->enqueueMessage($ex->getMessage(), 'error');

				return false;
			}

			// Get the new item ID
			$newId = $table->get('id');

			// Add the new ID to the array
			$newIds[$i] = $newId;
			$i++;
		}

		// Clean the cache
		$this->cleanCache();

		return $newIds;
	}

	/**
	 * Method to test whether a record can be deleted.
	 *
	 * @param   object $record A record object.
	 *
	 * @return  boolean  True if allowed to delete the record. Defaults to the permission set in the component.
	 *
	 * @since   1.6
	 */
	protected function canDelete($record)
	{
		if (!empty($record->id))
		{
			if ($record->state != -2)
			{
				return;
			}
			$user = JFactory::getUser();

			if (!empty($record->catid))
			{
				return $user->authorise('core.delete', 'com_simplecalendar.category.' . (int) $record->catid);
			}
			else
			{
				return parent::canDelete($record);
			}
		}
	}

	/**
	 * Method to test whether a record can have its state changed.
	 *
	 * @param   object $record A record object.
	 *
	 * @return  boolean  True if allowed to change the state of the record. Defaults to the permission set in the component.
	 *
	 * @since   1.6
	 */
	protected function canEditState($record)
	{
		$user = JFactory::getUser();

		// Check against the category.
		if (!empty($record->catid))
		{
			return $user->authorise('core.edit.state', 'com_simplecalendar.category.' . (int) $record->catid);
		}
		// Default to component settings if category not known.
		else
		{
			return parent::canEditState($record);
		}
	}

	/**
	 * Returns a JTable object, always creating it.
	 *
	 * @param   string $type   The table type to instantiate. [optional]
	 * @param   string $prefix A prefix for the table class name. [optional]
	 * @param   array  $config Configuration array for model. [optional]
	 *
	 * @return  JTable  A database object
	 *
	 * @since   1.6
	 */
	public function getTable($type = 'Event', $prefix = 'SimplecalendarTable', $config = array())
	{
		return JTable::getInstance($type, $prefix, $config);
	}

	/**
	 * Method to get the record form.
	 *
	 * @param   array   $data     Data for the form. [optional]
	 * @param   boolean $loadData True if the form is to load its own data (default case), false if not. [optional]
	 *
	 * @return  mixed  A JForm object on success, false on failure
	 *
	 * @since   3.0
	 */
	public function getForm($data = array(), $loadData = true)
	{
		// Get the form.
		$form = $this->loadForm('com_simplecalendar.event', 'event', array('control' => 'jform', 'load_data' => $loadData));

		if (empty($form))
		{
			return false;
		}

		$user = JFactory::getUser();

		if (!empty($data['id']))
		{
			$assetName = $this->option . '.event.' . $data['id'];

			$canEdit      = $user->authorise('core.edit', $assetName);
			$canEditOwn   = $user->authorise('core.edit.own', $assetName);
			$canEditState = $user->authorise('core.edit.state', $assetName);
		}
		else
		{
			$canEdit = $user->authorise('core.create', $this->option);
		}

		if (!$canEdit)
		{
			JFactory::getApplication()->enqueueMessage(JText::_('COM_SIMPLECALENDAR_NOT_ALLOWED_TO_EDIT'), 'error');

			return false;
		}

		// Determine correct permissions to check.
		if ($this->getState('event.id'))
		{
			// Existing record. Can only edit in selected categories.
			$form->setFieldAttribute('catid', 'action', 'core.edit');
		}
		else
		{
			// New record. Can only create in selected categories.
			$form->setFieldAttribute('catid', 'action', 'core.create');
		}

		// Modify the form based on access controls.
		if (!$this->canEditState((object) $data))
		{
			// Disable fields for display.
			$form->setFieldAttribute('ordering', 'disabled', 'true');
			// $form->setFieldAttribute('publish_up', 'disabled', 'true');
			// $form->setFieldAttribute('publish_down', 'disabled', 'true');
			$form->setFieldAttribute('state', 'disabled', 'true');

			// Disable fields while saving.
			// The controller has already verified this is a record you can edit.
			$form->setFieldAttribute('ordering', 'filter', 'unset');
			// $form->setFieldAttribute('publish_up', 'filter', 'unset');
			// $form->setFieldAttribute('publish_down', 'filter', 'unset');
			$form->setFieldAttribute('state', 'filter', 'unset');
		}

		// Special methods to allow for correct date-time handling
		$hour   = date('H', strtotime($form->getValue('start_dt')));
		$minute = date('i', strtotime($form->getValue('start_dt')));

		$form->setValue('start_time', $hour . ':' . $minute);

		return $form;
	}

	/**
	 * Method to get the data that should be injected in the form.
	 *
	 * @return  mixed  The data for the form.
	 *
	 * @since   1.6
	 */
	protected function loadFormData()
	{
		// Check the session for previously entered form data.
		$app  = JFactory::getApplication();
		$data = $app->getUserState('com_simplecalendar.edit.event.data', array());

		if (empty($data))
		{
			$data = $this->getItem();

			// Prime some default values.
			if ($this->getState('event.id') == 0)
			{
				$data->set('catid', $app->input->getInt('catid', $app->getUserState('com_simplecalendar.calendar.filter.category_id')));
			}
		}

		return $data;
	}

	/**
	 * A protected method to get a set of ordering conditions.
	 *
	 * @param   JTable $table A record object.
	 *
	 * @return  array  An array of conditions to add to add to ordering queries.
	 *
	 * @since   1.6
	 */
	// protected function getReorderConditions($table)
	// {
	// $condition = array();
	// $condition[] = 'catid = '. (int) $table->catid;
	// $condition[] = 'published >= 0';
	// return $condition;
	// }

	/**
	 * @since  3.0
	 */
	protected function prepareTable($table)
	{
		$params = JComponentHelper::getParams('com_simplecalendar');
		$date   = JFactory::getDate();
		$user   = JFactory::getUser();

		if (empty($table->id))
		{
			// Set the values
			$table->created_dt = $date->toSql();
			$table->created_by = $user->get('id');
		}
		else
		{
			// Set the values
			$table->modified_dt = $date->toSql();
			$table->modified_by = $user->get('id');
		}

		//TODO Check if this is still needed?
		/*if (empty($table->id) && $params->get('frontend_approve', '0') == '1')
		{
			// Set state to Suspended for new events that require approval
			$table->state = '0';
		}*/
	}

	/**
	 * Method to toggle the featured setting of events.
	 *
	 * @param   array    The ids of the items to toggle.
	 * @param   integer  The value to toggle to.
	 *
	 * @return  boolean  True on success.
	 */
	public function featured($pks, $value = 0)
	{
		// Sanitize the ids.
		$pks = (array) $pks;
		\Joomla\Utilities\ArrayHelper::toInteger($pks);

		if (empty($pks))
		{
			JFactory::getApplication()->enqueueMessage(JText::_('COM_CONTENT_NO_ITEM_SELECTED'), 'error');

			return false;
		}

		try
		{
			$db = $this->getDbo();

			$db->setQuery(
				'UPDATE #__simplecalendar' .
				' SET featured = ' . (int) $value .
				' WHERE id IN (' . implode(',', $pks) . ')'
			);
			$db->execute();

		} catch (Exception $e)
		{
			JFactory::getApplication()->enqueueMessage($e->getMessage(), 'error');

			return false;
		}
		$this->cleanCache();

		return true;
	}
}
