<?php
/**
 *    com_simplecalendar - a simple calendar component for Joomla
 *  Copyright (C) 2008-2013 Fabrizio Albonico
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *    (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

defined('_JEXEC') or die;

/**
 * Banner table
 *
 * @package     Joomla.Administrator
 * @subpackage  com_banners
 * @since       1.5
 */
class SimplecalendarTableEvent extends JTable
{
	/**
	 * Constructor
	 *
	 * @since   1.5
	 */
	public function __construct(&$_db)
	{
		parent::__construct('#__simplecalendar', 'id', $_db);
		$date             = JFactory::getDate();
		$this->created_dt = $date->toSql();
	}

	/**
	 * Function to increment the hits counter.
	 *
	 * @since 3.0
	 */
	public function hits()
	{
		$query = 'UPDATE #__simplecalendar'
			. ' SET hits = (hits + 1)'
			. ' WHERE id = ' . (int) $this->id;

		$this->_db->setQuery($query);
		$this->_db->execute();
	}

	/**
	 * Overloaded check function
	 *
	 * @return  boolean
	 * @see     JTable::check
	 * @since   1.5
	 */
	public function check()
	{
		// Set name
		$this->name = htmlspecialchars_decode($this->name, ENT_QUOTES);

		// Set alias
		$this->alias = JApplicationHelper::stringURLSafe($this->alias);

		if (empty($this->alias))
		{
			$this->alias = JApplicationHelper::stringURLSafe($this->name);
		}

		$config = JFactory::getConfig();
		$offset = $config->get('offset');

		// encode date and time
		date_default_timezone_set($offset);

		$start_dt = new JDate($this->start_dt);
		$this->start_dt = $start_dt->toSql();

		$start_time = $this->start_time;

		// Check for empty time
		if ($start_time == '')
		{
			$start_time = '50:00:00';
		}

		$this->start_time = $start_time;

		// Check end date for values
		if ($this->end_dt == '')
		{
			$this->end_dt = $this->getDbo()->getNullDate();
		}
		else
		{
			$end_dt = new JDate($this->end_dt);
			$this->end_dt = $end_dt->toSql();
		}

		// Check for end time (if available)
		$end_time = $this->end_time;

		if ($end_time == '')
		{
			$end_time = '50:00:00';
		}

		$this->end_time = $end_time;

		// Check the reserve date for values
		if ($this->reserve_dt == '')
		{
			$this->reserve_dt = $this->getDbo()->getNullDate();
		}
		else
		{
			$reserve_dt = new JDate($this->reserve_dt);
			$this->reserve_dt = $reserve_dt->toSql();
		}

		// Sanitize URL input: add http:// to website URL if available
		if ($this->contact_website != '' &&
			substr($this->contact_website, 0, 7) != 'http://' &&
			substr($this->contact_website, 0, 8) != 'https://'
		)
		{
			$this->contact_website = 'http://' . $this->contact_website;
		}

		return true;
	}

	/**
	 * Overloaded bind function
	 *
	 * @param   array $hash named array
	 *
	 * @return  null|string    null is operation was satisfactory, otherwise returns an error
	 * @see   JTable:bind
	 * @since 1.5
	 */
	public function bind($array, $ignore = array())
	{
		if (isset($array['params']) && is_array($array['params']))
		{
			// Convert the params field to a string.
			$parameter = new JRegistry;
			$parameter->loadArray($array['params']);
			$array['params'] = (string) $parameter;
		}

		// Bind the rules.
		if (isset($array['rules']) && is_array($array['rules']))
		{
			$rules = new JAccessRules($array['rules']);
			$this->setRules($rules);
		}

		return parent::bind($array, $ignore);

	}

	/**
	 * Method to store a row
	 *
	 * @param boolean $updateNulls True to update fields even if they are null.
	 */
	public function store($updateNulls = true)
	{
		$date   = JFactory::getDate();
		$user   = JFactory::getUser();
		$params = JComponentHelper::getParams('com_simplecalendar');
		$table  = JTable::getInstance('Event', 'SimplecalendarTable');
		$task   = JFactory::getApplication()->input->post->get('task');

		if (empty($this->id))
		{
			// New item
			$this->created_dt = $date->toSql();
			$this->created_by = $user->get('id');

			// Check that we have permission to save the event
			if ($user->get('id') == 0 && $params->get('frontend_approve', '1') == '1')
			{
				$this->state = 0;
			}

			// Verify that the alias is unique // in case of event copy
			if ($table->load(array('alias' => $this->alias, 'catid' => $this->catid)) && ($table->id != $this->id || $this->id == 0))
			{
				if ($task == 'save2copy')
				{
					$this->name  = $this->name . ' (copy)';
					$this->alias = 'copy-of-' . $this->alias;
				}
				else
				{
					$this->alias = $this->alias . '-' . substr(md5(date('H:i:s')), 0, 7);
				}

			}

			// Store the row
			if (!$this->check())
			{
				return false;
			}

			try
			{
				parent::store($updateNulls);
			} catch (Exception $ex)
			{
				JFactory::getApplication()->enqueueMessage(JText::_('SOME_ERROR_OCCURRED'), 'error');

				return false;
			}

			if ($this->recur_end_after > 0)
			{
				// TODO $this->id contains the new ID of the saved element
				$firstId    = $this->id;
				$firstAlias = $this->alias;
				$firstName  = $this->name;

				for ($i = 1; $i < (int) $this->recur_end_after; $i++)
				{
					// Reset the id
					$this->id = null;

					switch ($this->recur_every)
					{
						case '1':
						case '7':
							// Daily + weekly recurrence
							$this->start_dt = date('Y-m-d', strtotime($this->start_dt . '+' . (int) $this->recur_every . ' days'));

							if ($this->end_dt != $this->getDbo()->getNullDate())
							{
								$this->end_dt = date('Y-m-d', strtotime($this->end_dt . '+' . (int) $this->recur_every . ' days'));
							}

							if ($this->reserve_dt != $this->getDbo()->getNullDate())
							{
								$this->reserve_dt = date('Y-m-d', strtotime($this->reserve_dt . '+' . (int) $this->recur_every . ' days'));
							}

							break;
						case '30':
							// Monthly recurrence
							$this->start_dt = date('Y-m-d', strtotime($this->start_dt . '+1 months'));

							if ($this->end_dt != $this->getDbo()->getNullDate())
							{
								$this->end_dt = date('Y-m-d', strtotime($this->end_dt . ' +1 months'));
							}

							if ($this->reserve_dt != $this->getDbo()->getNullDate())
							{
								$this->reserve_dt = date('Y-m-d', strtotime($this->reserve_dt . ' +1 months'));
							}

							break;
						default:
							JFactory::getApplication()->enqueueMessage(JText::_('SOME_ERROR_OCCURRED'), 'error');
							break;

					} // End switch

					$this->name  = $firstName . ' (' . $i . ')';
					$this->alias = $firstAlias . '-' . $i;

					try
					{
						parent::store($updateNulls);
					} catch (Exception $ex)
					{
						JFactory::getApplication()->enqueueMessage(JText::_('SOME_ERROR_OCCURRED'), 'error');

						return false;
					}
				}

				$this->id = $firstId;
			}
		}
		else
		{
			// Existing item
			$this->modified_dt = $date->toSql();
			$this->modified_by = $user->get('id');

			// Get the old row
			$oldrow = JTable::getInstance('Event', 'SimplecalendarTable');

			if (!$oldrow->load($this->id) && $oldrow->getError())
			{
				JFactory::getApplication()->enqueueMessage($oldrow->getError(), 'error');
			}

			// Verify that the alias is unique
			$table = JTable::getInstance('Event', 'SimplecalendarTable');

			if ($table->load(array('alias' => $this->alias, 'catid' => $this->catid)) && ($table->id != $this->id || $this->id == 0))
			{
				JFactory::getApplication()->enqueueMessage(JText::_('COM_SIMPLECALENDAR_ERROR_UNIQUE_ALIAS'), 'error');

				return false;
			}

			// Store the new row
			parent::store(false);

			//TODO Joomla error... :( Waiting for fix
			// http://joomlacode.org/gf/project/joomla/tracker/?action=TrackerItemEdit&tracker_id=8103&tracker_item_id=28322
			// http://forum.joomla.org/viewtopic.php?f=728&t=803071
		}

		return count($this->getErrors()) == 0;
	}

	/**
	 * Method to set the publishing state for a row or list of rows in the database
	 * table.  The method respects checked out rows by other users and will attempt
	 * to checkin rows that it can after adjustments are made.
	 *
	 * @param   mixed     An optional array of primary key values to update.  If not
	 *                    set the instance property value is used.
	 * @param   integer   The publishing state. eg. [0 = unpublished, 1 = published, 2=archived, -2=trashed]
	 * @param   integer   The user id of the user performing the operation.
	 *
	 * @return  boolean  True on success.
	 * @since   1.6
	 */
	public function publish($pks = null, $state = 1, $userId = 0)
	{
		$k = $this->_tbl_key;

		// Sanitize input.
		JArrayHelper::toInteger($pks);
		$userId = (int) $userId;
		$state  = (int) $state;

		// If there are no primary keys set check to see if the instance key is set.
		if (empty($pks))
		{
			if ($this->$k)
			{
				$pks = array($this->$k);
			}
			// Nothing to set publishing state on, return false.
			else
			{
				$this->setError(JText::_('JLIB_DATABASE_ERROR_NO_ROWS_SELECTED'));

				return false;
			}
		}

		// Get an instance of the table
		$table = JTable::getInstance('Event', 'SimplecalendarTable');

		// For all keys
		foreach ($pks as $pk)
		{
			// Load the banner
			if (!$table->load($pk))
			{
				$this->setError($table->getError());
			}

			// Verify checkout
			// if ($table->checked_out == 0 || $table->checked_out == $userId)
			// {
			// // Change the state
			$table->state = $state;
			// $table->checked_out = 0;
			// $table->checked_out_time = $this->_db->getNullDate();

			// Check the row
			$this->check();

			// Store the row
			if (!$table->store())
			{
				$this->setError($table->getError());
			}
			// }
		}

		return count($this->getErrors()) == 0;
	}

	/**
	 * Redefined asset name, as we support action control
	 */
	protected function _getAssetName()
	{
		$k = $this->_tbl_key;

		return 'com_simplecalendar.event.' . (int) $this->$k;
	}

	/**
	 * Redefined asset title, as we support action control
	 */
	protected function _getAssetTitle()
	{
		// $k = $this->_tbl_key;

		return $this->name;
	}

	/**
	 * We provide our global ACL as parent
	 *
	 * @see JTable::_getAssetParentId()
	 */
	protected function _getAssetParentId(JTable $table = null, $id = null)
	{
		// We will retrieve the parent-asset from the Asset-table
		$assetParent = JTable::getInstance('Asset');
		// Default: if no asset-parent can be found we take the global asset
		$assetParentId = $assetParent->getRootId();
		// Find the parent-asset
		if (($this->catid) && !empty($this->catid))
		{
			// The item has a category as asset-parent
			$assetParent->loadByName('com_simplecalendar.category.' . (int) $this->catid);
		}
		else
		{
			// The item has the component as asset-parent
			$assetParent->loadByName('com_simplecalendar');
		}
		// Return the found asset-parent-id
		if ($assetParent->id)
		{
			$assetParentId = $assetParent->id;
		}

		return $assetParentId;
	}
}

